tkmilan.fn
==========

.. automodule:: tkmilan.fn

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      ask_directory_load
      ask_directory_save
      ask_file_load
      ask_file_save
      bind_mousewheel
      binding_disable
      configure_grid
      generate_trace
      grid_size
      label_size
      vname
   
   

   
   
   

   
   
   



